# vim-sourcer

The purpose of this plugin is to make the sourcing vim-files easier and faster.
It's basically an extension and, in my humble opinion, an improvment of the
`:source` command. Currently it contains the four commands for sourcing
vimscript-files: `:Source`, `:SourceDirs`, `:SourceBufs` and `:SourceWins`.

### Usage

The supplied commands functions as follows:
```vim
:Source     myfile.vim other.vim      " Source files, multiple arguments allowed
:SourceDirs ~/mydir                   " Sources vim-files in directory supplied
:SourceDirs ~/mydir ~/otherdir        " Also works with multiple dirs
:SourceDirs R=3 ~/mydir               " Source subdirs recursively 3 dirs down
:SourceBufs                           " Source vim-files in open buffers
:SourceWins                           " Source vim-files in visible windows
```
If no argument is provided to the `:Source` command it will source the current
file. The same goes for `:SourceDirs` but with the current working directory.

Some recommended mappings I use a lot when messing around with vimscript:
```vim
nnoremap <silent> <Leader>s :Source<CR>
nnoremap <silent> <Leader><S-s> :SourceBufs<CR>
```

### Configuration

 * `g:sourcer_source_loaded=1` makes vim-sourcer unlet `g:{script}_loaded`
   variables in order to properly source loaded scripts and plugins. It's
   (enabled) by default but you can disable it in your init-file.
 * `g:sourcer_verbose_output=1` makes the commands print a more verbose output.

### Installation

Use your favourite plugin-manager, for example
[vim-plug](https://github.com/junegunn/vim-plug):
```vim
Plug 'carlsmedstad/vim-sourcer'
```
For a manual install just copy the files into your `~/.vim` directory, or
`~/.config/nvim` for NeoVim.

### Contact

Feel free to contact me for questions, suggestions or issues at my twitter
[@carlsmedstad](https://twitter.com/carlsmedstad).

### License

MIT License. Copyright (c) 2017 Carl Smedstad.
